@@ -231,7 +231,7 @@ class SSHClient(object):
     def exec(self, cmd, promt_response=[], timeout=60):
         log.info(f"{self.__ip}:{self.__port} | exec cmd:{cmd},promt_response: {promt_response},timeout:{timeout}")
         try:
-            if not self.__ssh or not self.__ssh.is_active():
+            if not self.__ssh or not self.ssh_is_active():
                 log.warning(f"{self.__ip}:{self.__port} | ssh transport is inactive, try reconnect...")
                 if not self.reconnect():
                     log.error(f"{self.__ip}:{self.__port} | ssh reconnect failed, transport is not active.")
